@@ -32,7 +32,8 @@ globalVariables(c(".N","event_classifier", "activity_instance_classifier", "abso
 				  "duration", "start_timestamp","complete_timestamp", "complete","e","r","min_timestamp","max_rank","trace_id","act_freq",
 				  "s","dur","start", "relative_frequency","tot_dur","number_of_repetitions","denom", "instance",
 				  "total_length","perc", "relative","activity_frequency","absolute_trace_coverage","instances",
-				  "cnt", "trace_frequency", "V1","V2",".","event_id","freq", "element_type"))
+				  "cnt", "trace_frequency", "V1","V2",".","event_id","freq", "element_type", "min_r","max_r","endpoints",
+				  "ts","next_event","next_act","next_r","remove_next"))
 
 
 NULL
